# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_gem.models.gem_gem_remote import GemGemRemote

class TestGemGemRemote(unittest.TestCase):
    """GemGemRemote unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GemGemRemote:
        """Test GemGemRemote
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GemGemRemote`
        """
        model = GemGemRemote()
        if include_optional:
            return GemGemRemote(
                name = '0',
                url = '0',
                pulp_labels = {
                    'key' : ''
                    },
                policy = 'immediate',
                ca_cert = '0',
                client_cert = '0',
                client_key = '0',
                tls_validation = True,
                proxy_url = '0',
                proxy_username = '0',
                proxy_password = '0',
                username = '0',
                password = '0',
                max_retries = 56,
                total_timeout = 0.0,
                connect_timeout = 0.0,
                sock_connect_timeout = 0.0,
                sock_read_timeout = 0.0,
                headers = [
                    None
                    ],
                download_concurrency = 1,
                rate_limit = 56,
                prereleases = True,
                includes = {
                    'key' : ''
                    },
                excludes = {
                    'key' : ''
                    }
            )
        else:
            return GemGemRemote(
                name = '0',
                url = '0',
        )
        """

    def testGemGemRemote(self):
        """Test GemGemRemote"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PolicyEnum(str, Enum):
    """
    * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.
    """

    """
    allowed enum values
    """
    IMMEDIATE = 'immediate'
    ON_DEMAND = 'on_demand'
    STREAMED = 'streamed'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PolicyEnum from a JSON string"""
        return cls(json.loads(json_str))


